= net/protocol.rb internal documentation

== Net::Command

=== Super Class

Object

=== Class Methods

: new( socket )
  This method create new Command object. 'socket' must be ProtocolSocket.
  This method is abstract class.

=== Methods

: quit
  This method dispatch command which ends the protocol.



== Net::ProtocolSocket

=== Super Class

Object

=== Class Methods

: new( address = 'localhost', port = nil )
  This create new ProtocolSocket object, and connect to server.

=== Methods

: close
  This method closes socket.

: address, addr
  a FQDN address of server

: ip_address, ipaddr
  an IP address of server

: port
  connecting port number.

: closed?
  true if ProtocolSokcet have been closed already


: read( length )
  This method read 'length' bytes and return the string.

: readuntil( target )
  This method read until find 'target'. Returns read string.

: readline
  read until "\r\n" and returns it without "\r\n".

: read_pendstr
  This method read until "\r\n.\r\n".
  At the same time, delete period at line head and final line ("\r\n.\r\n").

: read_pendlist
: read_pendlist{|line| .... }
  This method read until "\r\n.\r\n". This method resembles to 'read_pendstr',
  but 'read_pendlist' don't check period at line head, and returns array which
  each element is one line.

  When this method was called with block, evaluate it for each reading a line.

: write( str )
  This method send 'str'. returns written length (bytes).

: write_bin( src )
  This method send 'src'. ProtocolSokcet read string from 'src' by 'each'
  iterator. This method returns written bytes.

: writeline( str )
  This method writes 'str'. There has not to be bare "\r" or "\n" in 'str'.

: write_pendstr( src )
  This method writes 'src' as a mail.
  ProtocolSocket reads strings from 'src' by 'each' iterator.
  This returns written bytes.



= net/smtp.rb internal documentation


== Net::SMTPCommand

=== Super Class

Net::Command

=== Class Methods

: new( socket )
  This method creates new SMTPCommand object, and open SMTP.

=== Methods

: helo( helo_domain )
  This method send "HELO" command and start SMTP.
  helo_domain is localhost's FQDN.

: mailfrom( from_addr )
  This method sends "MAIL FROM" command.
  from_addr is your mail address (xxxx@xxxx)

: rcpt( to_addrs )
  This method sends "RCPT TO" command.
  to_addrs is array of mail address (xxxx@xxxx) of destination.

: data
  This method sends "DATA" command.

: write_mail( mailsrc )
: write_mail {|socket| ... }
  send 'mailsrc' as mail.
  SMTPCommand reads strings from 'mailsrc' by calling 'each' iterator. 
  When iterator, SMTPCommand only stand by socket and pass it.
  (The socket will accepts only 'in_write' method in the block)

: quit
  This method sends "QUIT" command and ends SMTP session.



= net/pop.rb internal documentation


== Net::POP3Command

POP3 command class.

=== Super Class

Net::Command

=== Class Methods

: new( socket )
  This method creates new POP3Command object. 'socket' must be ProtocolSocket.

=== Methods

: auth( account, password )
  This method do POP authorization (no RPOP)
  In case of failed authorization, raises Protocol::ProtocolError exception.

: list
  a list of mails which existing on server.
  The list is an array like "array[ number ] = size".

  ex:

    The list from server is

    1 2452
    2 3355
    4 9842
       :

    then, an array is

    [ nil, 2452, 3355, nil, 9842, ... ]

: quit
  This method ends POP using 'QUIT' commmand.

: rset
  This method reset all changes done in current session,
  by sending 'RSET' command.

: top( num, lines = 0 )
  This method gets all mail header and 'lines' lines body
  by sending 'TOP' command.  'num' is mail number.

  WARNING: the TOP command is 'Optional' in RFC1939 (POP3)

: retr( num : Integer )
  This method gets a mail by 'RETR' command. 'num' is mail number.

: dele( num : Integer )
  This method deletes a mail on server by 'DELE'.


== APOPCommand

=== Super Class

POP3Command

=== Methods

: auth( account, password )
  This method do authorization by sending 'APOP' command.
  If server is not APOP server, this raises Net::ProtoAuthError exception.
  On other errors, raises Net::ProtocolError.
